==> intercom-sdk-base-3.0.18-sources.jar: io/intercom/android/sdk/push/SystemNotificationManager.java <==
package io.intercom.android.sdk.push;

import android.app.Notification;
import android.app.NotificationManager;
import android.content.Context;
import android.support.annotation.VisibleForTesting;

import java.util.ArrayList;
import java.util.List;

import io.intercom.android.sdk.logger.IntercomLogger;

public class SystemNotificationManager {
    private static final int NOTIFICATION_ID = 9999997;

    @VisibleForTesting final List<PushPayload> receivedPayloads = new ArrayList<>();

    private final SystemNotificationFactory systemNotificationFactory;
    private final NotificationManager androidNotificationManager;

    public SystemNotificationManager(NotificationManager androidNotificationManager) {
        this(androidNotificationManager, new SystemNotificationFactory());
    }

    @VisibleForTesting SystemNotificationManager(NotificationManager androidNotificationManager,
                                                 SystemNotificationFactory systemNotificationFactory) {
        this.androidNotificationManager = androidNotificationManager;
        this.systemNotificationFactory = systemNotificationFactory;
    }

    public void clear() {
        if (!receivedPayloads.isEmpty()) {
            IntercomLogger.i("Removing Intercom push notifications.");
        }

        androidNotificationManager.cancel(NOTIFICATION_ID);
        receivedPayloads.clear();
    }

    void createPushOnlyNotification(PushPayload payload, Context context) {
        Notification notification = systemNotificationFactory.createPushOnlyNotification(payload, context);
        String pushOnlyConversationId = payload.getPushOnlyConversationId();
        androidNotificationManager.notify(pushOnlyConversationId, pushOnlyConversationId.hashCode(), notification);
    }

    void createNotification(PushPayload payload, Context context) {
        for (PushPayload current : receivedPayloads) {
            // Hacky way to check for duplicate pushes.
            // This is caused by the device having multiple working tokens registered
            if (current.equals(payload)) {
                return;
            }
        }

        receivedPayloads.add(payload);

        Notification notification;

        if (receivedPayloads.size() == 1) {
            notification = systemNotificationFactory.createSingleNotification(payload, context);
        } else {
            notification = systemNotificationFactory.createGroupedNotification(receivedPayloads, context);
        }

        androidNotificationManager.notify(NOTIFICATION_ID, notification);
    }
}

==> intercom-sdk-base-3.0.20-sources.jar: io/intercom/android/sdk/push/SystemNotificationManager.java <==
package io.intercom.android.sdk.push;

import android.app.Notification;
import android.app.NotificationManager;
import android.content.Context;
import android.support.annotation.VisibleForTesting;

import com.intercom.twig.Twig;

import java.util.ArrayList;
import java.util.List;

import io.intercom.android.sdk.logger.TwigFactory;

public class SystemNotificationManager {
    private static final int NOTIFICATION_ID = 9999997;

    @VisibleForTesting final List<PushPayload> receivedPayloads = new ArrayList<>();

    private final Twig twig = TwigFactory.getLogger();
    private final SystemNotificationFactory systemNotificationFactory;
    private final NotificationManager androidNotificationManager;

    public SystemNotificationManager(NotificationManager androidNotificationManager) {
        this(androidNotificationManager, new SystemNotificationFactory());
    }

    @VisibleForTesting SystemNotificationManager(NotificationManager androidNotificationManager,
                                                 SystemNotificationFactory systemNotificationFactory) {
        this.androidNotificationManager = androidNotificationManager;
        this.systemNotificationFactory = systemNotificationFactory;
    }

    public void clear() {
        if (!receivedPayloads.isEmpty()) {
            twig.i("Removing Intercom push notifications.");
        }

        androidNotificationManager.cancel(NOTIFICATION_ID);
        receivedPayloads.clear();
    }

    void createPushOnlyNotification(PushPayload payload, Context context) {
        Notification notification = systemNotificationFactory.createPushOnlyNotification(payload, context);
        String pushOnlyConversationId = payload.getPushOnlyConversationId();
        androidNotificationManager.notify(pushOnlyConversationId, pushOnlyConversationId.hashCode(), notification);
    }

    void createNotification(PushPayload payload, Context context) {
        for (PushPayload current : receivedPayloads) {
            // Hacky way to check for duplicate pushes.
            // This is caused by the device having multiple working tokens registered
            if (current.equals(payload)) {
                return;
            }
        }

        receivedPayloads.add(payload);

        Notification notification;

        if (receivedPayloads.size() == 1) {
            notification = systemNotificationFactory.createSingleNotification(payload, context);
        } else {
            notification = systemNotificationFactory.createGroupedNotification(receivedPayloads, context);
        }

        androidNotificationManager.notify(NOTIFICATION_ID, notification);
    }
}
